# Table of Contents

- [pull-webhooks](<./pull-webhooks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [PULL Webhooks](<./PULL-Webhooks.md>)
  - [Intended Usage](<./PULL-Webhooks/Intended-Usage.md>)
  - [Concurrency](<./PULL-Webhooks/Concurrency.md>)
  - [Event Availability](<./PULL-Webhooks/Event-Availability.md>)
  - [Automatic Deactivation of PULL Webhooks](<./PULL-Webhooks/Automatic-Deactivation-of-PULL-Webhooks.md>)
  - [Retrieving Events](<./PULL-Webhooks/Retrieving-Events.md>)
  - [Moving the Cursor](<./PULL-Webhooks/Moving-the-Cursor.md>)
